package org.opengroup.osdu.notification.provider.azure.util;

import com.azure.security.keyvault.secrets.SecretClient;
import com.azure.security.keyvault.secrets.models.KeyVaultSecret;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import javax.inject.Named;

@Configuration
public class AzureCosmosProperties {

    @Value("${tenantinfo.container.name}")
    private String tenantInfoContainerName;

    @Value("${azure.cosmosdb.database}")
    private String cosmosDBName;

    // TODO : Move away from Named beans.
    @Bean
    @Named("COSMOS_ENDPOINT")
    public String cosmosEndpoint(SecretClient kv) {
        return getKeyVaultSecret(kv, "opendes-cosmos-endpoint");
    }

    @Bean
    @Named("COSMOS_KEY")
    public String cosmosKey(SecretClient kv) {
        return getKeyVaultSecret(kv, "opendes-cosmos-primary-key");
    }

    @Bean
    @Named("COSMOS_CONTAINER_NAME")
    public String containerName() {
        return tenantInfoContainerName;
    }

    @Bean
    @Named("COSMOS_DB_NAME")
    public String cosmosDBName() {
        return cosmosDBName;
    }

    private String getKeyVaultSecret(SecretClient kv, String secretName) {
        KeyVaultSecret secret = kv.getSecret(secretName);
        if (secret == null) {
            throw new IllegalStateException(String.format("No secret found with name %s", secretName));
        }

        String secretValue = secret.getValue();
        if (secretValue == null) {
            throw new IllegalStateException(String.format(
                    "Secret unexpectedly missing from KeyVault response for secret with name %s", secretName));
        }

        return secretValue;
    }
}
